@@ -698,10 +698,18 @@ class AssessedRanges:
         :obj:`pd.DataFrame`
             :obj:`pd.DataFrame` containing the calculated metric values
             alongside other relevant metadata
+
+        Raises
+        ------
+        ValueError
+            Data required to calculate the metric is not available
         """
-        res_calc = res_calc.filter(
-            **self.get_variables_regions_scenarios_for_metric(metric)
-        )
+        filters = self.get_variables_regions_scenarios_for_metric(metric)
+        res_calc = res_calc.filter(**filters, log_if_empty=False)
+        if res_calc.empty:
+            raise ValueError(
+                "{} requires {} but it is not in the results".format(metric, filters)
+            )
 
         eval_method = self.get_col_for_metric(metric, "RCMIP evaluation method")
 
