@@ -7,3 +7,9 @@ class ProtocolConsistencyError(ValueError):
     """
     Inconsistency between input data and the RCMIP protocol
     """
+
+
+class NoDataForMetricError(ValueError):
+    """
+    No data available to calculate the given metric
+    """
