@@ -1,11 +1,11 @@
 """
 Calculation of the transient climate response (TCR)
 """
-from .base import Calculator
+from .base import _CalculatorTCRTCREBase
 from .utils import _time_mean
 
 
-class CalculatorTCR(Calculator):
+class CalculatorTCR(_CalculatorTCRTCREBase):
     """
     Calculator of the transient climate response (TCR)
     """
@@ -18,26 +18,17 @@ class CalculatorTCR(Calculator):
     def _calculate(
         cls, assessed_ranges, res_calc, norm_period, evaluation_period, unit
     ):
-        res_calc_normed = assessed_ranges._get_normed_res_calc(
-            res_calc, norm_period=range(1850, 1850 + 1)
+        res_calc_normed = cls._get_normed_res_calc(
+            assessed_ranges, res_calc, norm_period, evaluation_period
         )
 
-        if evaluation_period is not None and (
-            len(evaluation_period) != 1 or evaluation_period[0] != 1920
-        ):
-            raise NotImplementedError(
-                "Evaluation period other than [1920], input: {}".format(
-                    evaluation_period
-                )
-            )
-
         out = _time_mean(
             res_calc_normed.filter(
                 scenario="1pctCO2",
                 variable="Surface Air Temperature Change",
                 unit=unit,
                 region="World",
-                year=range(1920, 1921),
+                year=1920,
             )
         )
 
